==> dotnet6_6.0.136.orig.tar.xz: src/runtime/src/tests/JIT/Methodical/explicit/coverage/expl_gc_float_1.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;
using System.Runtime.InteropServices;

[StructLayout(LayoutKind.Explicit)]
internal class AA
{
    [FieldOffset(13)]
    public long tmp1;
    [FieldOffset(7)]
    public long tmp2;
    [FieldOffset(7)]
    public long tmp3;

    [FieldOffset(8)]
    public float q;

    [FieldOffset(36)]
    public int tmp4;
    [FieldOffset(44)]
    public long tmp5;
    [FieldOffset(39)]
    public uint tmp6;

    public AA(float qq)
    {
        tmp1 = 0;
        tmp2 = 0;
        tmp3 = 0;
        tmp4 = 0;
        tmp5 = 0;
        tmp6 = 0;
        q = qq;
    }

    public static AA[] a_init = new AA[101];
    public static AA[] a_zero = new AA[101];
    public static AA[,,] aa_init = new AA[1, 101, 2];
    public static AA[,,] aa_zero = new AA[1, 101, 2];
    public static object b_init = new AA(100);
    public static AA _init, _zero;

    public static float call_target(float arg) { return arg; }
    public static float call_target_ref(ref float arg) { return arg; }

    public void verify()
    {
    }

    public static void verify_all()
    {
        a_init[100].verify();
        a_zero[100].verify();
        aa_init[0, 99, 1].verify();
        aa_zero[0, 99, 1].verify();
        _init.verify();
        _zero.verify();
        BB.f_init.verify();
        BB.f_zero.verify();
    }

    public static void reset()
    {
        a_init[100] = new AA(100);
        a_zero[100] = new AA(0);
        aa_init[0, 99, 1] = new AA(100);
        aa_zero[0, 99, 1] = new AA(0);
        _init = new AA(100);
        _zero = new AA(0);
        BB.f_init = new AA(100);
        BB.f_zero = new AA(0);
    }
}

internal struct BB
{
    public static AA f_init, f_zero;
}

==> dotnet8_8.0.122-8.0.22.orig.tar.xz: src/runtime/src/tests/JIT/Methodical/explicit/coverage/expl_gc_float_1.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;
using System.Runtime.InteropServices;
using Xunit;

[StructLayout(LayoutKind.Explicit)]
internal class AA
{
    [FieldOffset(13)]
    public long tmp1;
    [FieldOffset(7)]
    public long tmp2;
    [FieldOffset(7)]
    public long tmp3;

    [FieldOffset(8)]
    public float q;

    [FieldOffset(36)]
    public int tmp4;
    [FieldOffset(44)]
    public long tmp5;
    [FieldOffset(39)]
    public uint tmp6;

    public AA(float qq)
    {
        tmp1 = 0;
        tmp2 = 0;
        tmp3 = 0;
        tmp4 = 0;
        tmp5 = 0;
        tmp6 = 0;
        q = qq;
    }

    public static AA[] a_init = new AA[101];
    public static AA[] a_zero = new AA[101];
    public static AA[,,] aa_init = new AA[1, 101, 2];
    public static AA[,,] aa_zero = new AA[1, 101, 2];
    public static object b_init = new AA(100);
    public static AA _init, _zero;

    public static float call_target(float arg) { return arg; }
    public static float call_target_ref(ref float arg) { return arg; }

    public void verify()
    {
    }

    public static void verify_all()
    {
        a_init[100].verify();
        a_zero[100].verify();
        aa_init[0, 99, 1].verify();
        aa_zero[0, 99, 1].verify();
        _init.verify();
        _zero.verify();
        BB.f_init.verify();
        BB.f_zero.verify();
    }

    public static void reset()
    {
        a_init[100] = new AA(100);
        a_zero[100] = new AA(0);
        aa_init[0, 99, 1] = new AA(100);
        aa_zero[0, 99, 1] = new AA(0);
        _init = new AA(100);
        _zero = new AA(0);
        BB.f_init = new AA(100);
        BB.f_zero = new AA(0);
    }
}

internal struct BB
{
    public static AA f_init, f_zero;
}

public static class Test_expl_gc_float_1
{
    [Fact]
    public static int TestEntrypoint()
    {
        return TestApp.RunAllTests();
    }
}
